@@ -111,12 +111,8 @@ module Protocol
 					# end
 					
 					return Response.wrap(env, status, headers, meta, body, request)
-				rescue => exception
-					Console.error(self, exception)
-					
-					body&.close if body.respond_to?(:close)
-					
-					return failure_response(exception)
+				rescue => error
+					return self.handle_error(env, status, headers, body, error)
 				end
 				
 				# Process the rack response headers into a {Protocol::HTTP::Headers} instance, along with any extra `rack.` metadata.
@@ -135,10 +131,10 @@ module Protocol
 							meta[key] = value
 						elsif value.is_a?(String)
 							value.split("\n").each do |value|
-								headers[key] = value
+								headers.add(key, value)
 							end
 						else
-							headers[key] = value
+							headers.add(key, value)
 						end
 					end
 					
